// Copyright (c) 2021 Tencent. All rights reserved.

#import "AppDelegate.h"
#import <TCMediaX/TCMediaX.h>

#define LICENCE_URL  @"..."  // URL
#define LICENCE_KEY  @"..."  // Key
#define MaxRetryCount  (3)  // 最大的重试次数

@interface AppDelegate ()<TCMediaXBaseDelegate>

@property (nonatomic, assign) NSInteger retryCount;

@end

@implementation AppDelegate

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {
    // Override point for customization after application launch.
    self.retryCount = 0;
    [[TCMediaXBase getInstance] setDelegate:self];
    [[TCMediaXBase getInstance] setLogEnable:YES];
    [[TCMediaXBase getInstance] setLicenceURL:LICENCE_URL key:LICENCE_KEY];
    return YES;
}

#pragma mark - TCMediaXBaseDelegate

- (void)onLicenseCheckCallback:(int)errcode withParam:(NSDictionary *)param {
    NSLog(@"TCMediaXBase setLicense authresult: %d ,errorMsg: %@", errcode, param);
    if (errcode == TMXLicenseCheckDownloadError
        || errcode == TMXLicenseCheckLocalLicenseEmpty) {
        
        if (self.retryCount < MaxRetryCount) {
            self.retryCount++;
            dispatch_async(dispatch_get_global_queue(DISPATCH_QUEUE_PRIORITY_DEFAULT, 0), ^{
                [[TCMediaXBase getInstance] setLicenceURL:LICENCE_URL key:LICENCE_KEY];
            });
        } else {
            // 业务侧提测用户异常
            self.retryCount = 0;
        }
    }
    
    // License检查OK
    if (errcode == TMXLicenseCheckOk) {
        self.retryCount = 0;
    }
}

#pragma mark - UISceneSession lifecycle


- (UISceneConfiguration *)application:(UIApplication *)application configurationForConnectingSceneSession:(UISceneSession *)connectingSceneSession options:(UISceneConnectionOptions *)options {
    // Called when a new scene session is being created.
    // Use this method to select a configuration to create the new scene with.
    return [[UISceneConfiguration alloc] initWithName:@"Default Configuration" sessionRole:connectingSceneSession.role];
}


- (void)application:(UIApplication *)application didDiscardSceneSessions:(NSSet<UISceneSession *> *)sceneSessions {
    // Called when the user discards a scene session.
    // If any sessions were discarded while the application was not running, this will be called shortly after application:didFinishLaunchingWithOptions.
    // Use this method to release any resources that were specific to the discarded scenes, as they will not return.
}


@end
